@@ -29,8 +29,6 @@ public final class Workarounds {
     private static final Object ACTIVITY_THREAD;
 
     static {
-        prepareMainLooper();
-
         try {
             // ActivityThread activityThread = new ActivityThread();
             ACTIVITY_THREAD_CLASS = Class.forName("android.app.ActivityThread");
@@ -77,19 +75,6 @@ public final class Workarounds {
         fillAppContext();
     }
 
-    @SuppressWarnings("deprecation")
-    private static void prepareMainLooper() {
-        // Some devices internally create a Handler when creating an input Surface, causing an exception:
-        //   "Can't create handler inside thread that has not called Looper.prepare()"
-        // <https://github.com/Genymobile/scrcpy/issues/240>
-        //
-        // Use Looper.prepareMainLooper() instead of Looper.prepare() to avoid a NullPointerException:
-        //   "Attempt to read from field 'android.os.MessageQueue android.os.Looper.mQueue'
-        //    on a null object reference"
-        // <https://github.com/Genymobile/scrcpy/issues/921>
-        Looper.prepareMainLooper();
-    }
-
     private static void fillAppInfo() {
         try {
             // ActivityThread.AppBindData appBindData = new ActivityThread.AppBindData();
